==> web-audio-engine-0.10.2.tgz: package/lib/api/OscillatorNode.js <==
"use strict";

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var impl = require("../impl");
var AudioNode = require("./AudioNode");
var AudioParam = require("./AudioParam");

var OscillatorNode = function (_AudioNode) {
  _inherits(OscillatorNode, _AudioNode);

  function OscillatorNode(context) {
    _classCallCheck(this, OscillatorNode);

    var _this = _possibleConstructorReturn(this, (OscillatorNode.__proto__ || Object.getPrototypeOf(OscillatorNode)).call(this, context));

    _this._impl = new impl.OscillatorNode(context._impl);
    _this._impl.$frequency = new AudioParam(context, _this._impl.getFrequency());
    _this._impl.$detune = new AudioParam(context, _this._impl.getDetune());
    _this._impl.$onended = null;
    return _this;
  }

  _createClass(OscillatorNode, [{
    key: "start",
    value: function start(when) {
      this._impl.start(when);
    }
  }, {
    key: "stop",
    value: function stop(when) {
      this._impl.stop(when);
    }
  }, {
    key: "setPeriodicWave",
    value: function setPeriodicWave(periodicWave) {
      this._impl.setPeriodicWave(periodicWave);
    }
  }, {
    key: "type",
    get: function get() {
      return this._impl.getType();
    },
    set: function set(value) {
      this._impl.setType(value);
    }
  }, {
    key: "frequency",
    get: function get() {
      return this._impl.$frequency;
    }
  }, {
    key: "detune",
    get: function get() {
      return this._impl.$detune;
    }
  }, {
    key: "onended",
    get: function get() {
      return this._impl.$onended;
    },
    set: function set(callback) {
      this._impl.replaceEventListener("ended", this._impl.$onended, callback);
      this._impl.$onended = callback;
    }
  }]);

  return OscillatorNode;
}(AudioNode);

module.exports = OscillatorNode;

==> web-audio-engine-0.13.1.tgz: package/lib/api/OscillatorNode.js <==
"use strict";

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var impl = require("../impl");
var AudioScheduledSourceNode = require("./AudioScheduledSourceNode");
var AudioParam = require("./AudioParam");

var OscillatorNode = function (_AudioScheduledSource) {
  _inherits(OscillatorNode, _AudioScheduledSource);

  function OscillatorNode(context, opts) {
    _classCallCheck(this, OscillatorNode);

    var _this = _possibleConstructorReturn(this, (OscillatorNode.__proto__ || Object.getPrototypeOf(OscillatorNode)).call(this, context));

    _this._impl = new impl.OscillatorNode(context._impl, opts);
    _this._impl.$frequency = new AudioParam(context, _this._impl.getFrequency());
    _this._impl.$detune = new AudioParam(context, _this._impl.getDetune());
    _this._impl.$onended = null;

    if (opts && opts.periodicWave) {
      _this.setPeriodicWave(opts.periodicWave);
    }
    return _this;
  }

  _createClass(OscillatorNode, [{
    key: "setPeriodicWave",
    value: function setPeriodicWave(periodicWave) {
      this._impl.setPeriodicWave(periodicWave);
    }
  }, {
    key: "type",
    get: function get() {
      return this._impl.getType();
    },
    set: function set(value) {
      this._impl.setType(value);
    }
  }, {
    key: "frequency",
    get: function get() {
      return this._impl.$frequency;
    }
  }, {
    key: "detune",
    get: function get() {
      return this._impl.$detune;
    }
  }]);

  return OscillatorNode;
}(AudioScheduledSourceNode);

module.exports = OscillatorNode;
